############################################################################
###                   CBC BELIZE ASSAY ANALYSIS                          ###
############################################################################

# Authors: Carmen Ritter, Leah Harper, and Jonathan Lefcheck
# Last updated: 5 OCTOBER 2021 by CJR
# Contact: RitterC@si.edu, HarperL@si.edu, LefcheckJ@si.edu

#---------------------------------------------------------------------------

# Load required libraries
library(car)
library(cowplot)
library(effects)
library(emmeans)
library(ggplot2)
library(gridExtra)
library(lme4)
library(lmtest)
library(lubridate)
library(nlme)
library(piecewiseSEM)
library(readxl)
library(rgeos)
library(tidyverse)
library(ggpubr)
library(dplyr)
library(vegan)
library(leaflet)
library(viridis)
library(rcompanion)
library(FSA)

# Set working directory

# Standard Error
se <- function(x)sqrt(var(x)/length(x))

#' pooled.sd : a function for computing pooled standard deviation
#' @param s a vector of sample standard deviations
#' @param n a vector of sample sizes associated with each sample SD
pooled.sd <- function(s, n) sqrt( sum(((n-1)*s^2)) / (sum(n) - length(n)) )

pd <- position_dodge(width = 0.4)

isSig <- function(p) {
  
  ifelse(p > 0.01 & p < 0.05, "*",
         ifelse(p > 0.001 & p <= 0.01, "**",
                ifelse(p <= 0.001, "***", "")))
  
}

habcolors = c('Fore Reef'='steelblue1','Patch Reef'='midnightblue','Mangrove'='sienna',
              'Bare Sand' = 'darkorange1', 'Seagrass' ='seagreen')

algcolors = c('Dictyota'='brown','Acanthophora'='red','Halimeda'='chartreuse3',
              'Sargassum' = 'goldenrod', 'Thalassia' ='forestgreen')

cbPalette <- c("#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")

####---------------------------------------------------------------------------
#### SETTING UP ENVIRONMENT AND DATA
####---------------------------------------------------------------------------

# Read in data
# 2017 Weedpops video observations data
wp <- read.csv("Weedpops_2017_Video_Data.csv")

# 2017 Squidpops video observations data
sp <- read_csv("Squidpops_2017_Video_Data.csv")

# 5 year weedpops data
assay <- read.csv("Weedpops_5Year_Data.csv")

# 5 year squidpops data
squid <- read.csv("Squidpops_5Year_Data.csv")

# 5 year RLS data
RLS_pops <- read.csv("CBC_RLS_squidpops.csv")

# 5 year RLS biomass data
RLSbiomass <- read_csv("RLSbiomass_curated.csv")

#######################
###### Figure 1 #######
#######################

# Information for each CBC study locality
sites <- read.csv(textConnection("
Habitat, Site,Lat,Long
Fore Reef, CBC Reef Central,	16.8021,	-88.0788
Fore Reef, South Reef Central,	16.77618,	-88.0754
Fore Reef, Tobacco Reef,	16.86828,	-88.0662
Mangrove, Blueground Mangrove,	16.80807,	-88.1468
Mangrove, Tobacco Mangrove,	16.87853,	-88.0926
Mangrove, Twin Cays Mangrove,	16.82878,	-88.1048
Patch Reef, CBC House Reef,	16.80126,	-88.0831
Patch Reef, CBC Lagoon Reef,	16.80863,	-88.0862
Patch Reef, Curlew Patch Reef,	16.78,	-88.1012
Sand, CBC Sand,	16.80894,	-88.0884
Sand, Curlew Sand,	16.78734,	-88.0938
Sand, Tobacco Sand,	16.88381,	-88.0734
Seagrass, Blueground Seagrass,	16.7981,	-88.11505
Seagrass, CBC Seagrass,	16.8025,	-88.0825
Seagrass, Curlew Seagrass,	16.78728,	-88.0851
Seagrass, Tobacco Seagrass,	16.87439,	-88.0938
Seagrass, Twin Cays Seagrass,	16.82385,	-88.1028
"))

reefs <- read.csv(textConnection("
Habitat, Site, Lat, Long
Fore Reef, CBC Reef Central,	16.8021,	-88.0788
Fore Reef, South Reef Central,	16.77618,	-88.0754
Fore Reef, Tobacco Reef,	16.86828,	-88.0662
Patch Reef, CBC House Reef,	16.80126,	-88.0831
Patch Reef, CBC Lagoon Reef,	16.80863,	-88.0862
Patch Reef, Curlew Patch Reef,	16.78,	-88.1012
"))

# Assign unique color to each habitat type
habColor <- colorFactor(c("steelblue1", "sienna", "midnightblue", "darkorange1", "seagreen"),
                        domain = c("Fore Reef", "Mangrove", "Patch Reef",
                                   "Sand", "Seagrass"))

# A map of all CBC sites
CBCsites <- leaflet(sites) %>%
  addProviderTiles(providers$Esri.WorldStreetMap) %>%
  addCircleMarkers(lng = ~Long, lat = ~Lat, weight = 1, 
                   radius = 20, popup = ~Site, fillColor = ~habColor(Habitat),
                   stroke = TRUE, color = "black", fillOpacity = 1.0) %>%
  addLegend("bottomright", habColor, values = ~Habitat,
            title = "Habitats",
            opacity = 1)
CBCsites  # Print the map

####---------------------------------------------------------------------------
#### ANALYSIS
####---------------------------------------------------------------------------

# Summarize weedpops proportion lost through time by habitat (24 hours)
assay.summary <- assay %>%
  
 mutate(
    # n = (Number.Deployed - StakesMissing.24hr),
    # value = Detachment.24hr/n,
    s = sqrt((value * (1 - value)/n))) %>%
  
  group_by(Habitat, AlgalType, Year) %>%
  
  summarize(
    medVal = median(value),
    value = mean(value),
    pooled.s = pooled.sd(s, n),
    pooled.se = pooled.s/sqrt(sum(n))
  )

# Summarize weedpops proportion lost through time by habitat (1 hour)
assay.summary.1hr <- assay %>%
  
  mutate(
    # n = (Number.Deployed - StakesMissing.24hr), - 24 bc not enough data for 1hr
    # value1 = Detachment.1hr/n,
    s = sqrt((value1 * (1 - value1)/n))) %>%
  
  group_by(Habitat, AlgalType, Year) %>%
  
  summarize(
    medvalue1 = median(value1),
    value1 = mean(value1),
    pooled.s = pooled.sd(s, n),
    pooled.se = pooled.s/sqrt(sum(n))
  )

# Summarize squidpops proportion lost through time by habitat (24 hours)
squid.summary <- squid %>% drop_na(Detachment.24hr)

squid.summary <- squid.summary %>%
  mutate(
    n.squid = as.numeric(stakes_remaining_24_hr),
    Detachment.24hr = as.numeric(Detachment.24hr),
    value.squid = Detachment.24hr/n.squid
  ) %>%
  
  mutate(
    s.squid = sqrt((value.squid * (1 - value.squid)/n.squid))
  ) %>%
  
  group_by(Habitat, Year) %>%
  
  summarize(
    medVal.squid = median(value.squid),
    meanVal.squid = mean(value.squid),
    pooled.s.squid = pooled.sd(s.squid, n.squid),
    pooled.se.squid = pooled.s.squid/sqrt(sum(n.squid))
  )

# Summarize squidpops proportion lost through time by habitat (1 hour)
squid.summary.1hr <- squid %>% drop_na(Detachment.1hr)

squid.summary.1hr <- squid.summary.1hr %>%
  mutate(
    n.squid.1hr = as.numeric(stakes_remaining_24_hr),
    Detachment.1hr = as.numeric(Detachment.1hr),
    value.squid.1hr = Detachment.1hr/n.squid.1hr
  ) %>%
  
  mutate(
    s.squid.1hr = sqrt((value.squid.1hr * (1 - value.squid.1hr)/n.squid.1hr))
  ) %>%
  
  group_by(Habitat, Year) %>%
  
  summarize(
    medVal.squid.1hr = median(value.squid.1hr),
    meanVal.squid.1hr = mean(value.squid.1hr),
    pooled.s.squid.1hr = pooled.sd(s.squid.1hr, n.squid.1hr),
    pooled.se.squid.1hr = pooled.s.squid.1hr/sqrt(sum(n.squid.1hr))
  )

# Return median values for weedpops at 24 hours
median24algal <-assay.summary %>%
  group_by(Habitat) %>%
  summarize(median = median(medVal))

# Return median values for weedpops at 1 hour
median1algal <-assay.summary.1hr %>%
  group_by(Habitat) %>%
  summarize(median = median(medvalue1))

# Return median values for squidpops at 24 hours
median24squid <-squid.summary %>%
  group_by(Habitat) %>%
  summarize(median = median(medVal.squid))

# Return median values for weedpops at 24 hours
median1squid <-squid.summary.1hr %>%
  group_by(Habitat) %>%
  summarize(median = median(medVal.squid.1hr))

#######################
###### Table 1 #######
#######################
# Model herbivory after one hour
habitat_model1hr <- glm(value1 ~ Habitat * AlgalType + Habitat*Year + location,
                        family = "quasibinomial",
                        data = assay)

# Get model results
Anova(habitat_model1hr, type = "II")

# Model herbivory after 24 hours
habitat_model <- glm(value ~ Habitat * AlgalType + Habitat*Year + location,
                     family = "quasibinomial",
                     data = assay)

# Get model results
Anova(habitat_model, type = "II")

#######################
###### Figure 2 #######
#######################

# See section "Table S3 + Figure 2" for Figure 2 code

#######################
###### Figure 3 #######
#######################
# Proportion macrophyte missing after 24 hours by algal type across 2015-2019

Figure3_24h <- ggplot(assay.summary, aes(x = Year, y = value, group = Habitat, col = Habitat)) +
    geom_line(size = 1) +
    geom_errorbar(aes(ymax = value + pooled.se, ymin = value - pooled.se), width = 0) +
    geom_point() +
    scale_color_manual(values = habcolors) +
    labs(x = "", y = "Mean Proportion Macrophytes lost +/- S.E. after 24 h") +
    facet_wrap(~ AlgalType, ncol = 1) +
    ylim(0.0,1.0) +
    theme_bw(base_size = 12) +
    theme(
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      legend.position = "none",
      axis.text.x = element_text(size = 15),
      axis.text.y = element_text(size = 15),
      strip.text = element_text(size = 20),
      axis.title = element_text(size = 18),
      panel.spacing.x = unit(2, "lines")
    )

# Proportion macrophyte missing after 1 hour by algal type across 2015-2019

Figure3_1h <- ggplot(assay.summary.1hr, aes(x = Year, y = value1, group = Habitat, col = Habitat)) +
    geom_line(size = 1) +
    geom_errorbar(aes(ymax = value1 + pooled.se, ymin = value1 - pooled.se), width = 0) +
    geom_point() +
    scale_color_manual(values = habcolors) +
    labs(x = "", y = "Mean Proportion Macrophytes lost +/- S.E. after 1 h") +
    facet_wrap(~ AlgalType, ncol = 1) +
    ylim(0.0,1.0) +
    theme_bw(base_size = 12) +
    theme(
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      legend.position = "none",
      axis.text.x = element_text(size = 15),
      axis.text.y = element_text(size = 15),
      strip.text = element_text(size = 20),
      axis.title = element_text(size = 18),
      panel.spacing.x = unit(2, "lines")
    )

# side-by-side 1 and 24 hour plots by algal type
(Figure3 <- plot_grid(Figure3_1h, Figure3_24h, ncol = 2, nrow = 1, labels = c("", "")))

#######################
###### Figure 4 #######
#######################
# Proportion squid missing after 24 hours across 2015-2019

(Figure4_24h <- ggplot(squid.summary, aes(x = Year, y = meanVal.squid, group = Habitat, col = Habitat)) +
  geom_line(size = 1) +
  geom_point(size = 3) +
  geom_errorbar(aes(ymax = meanVal.squid + pooled.se.squid, ymin = meanVal.squid - pooled.se.squid), width = 0) +
  scale_color_manual(values = habcolors) +
  labs(x = "", y = "Mean Proportion Squid Baits lost +/- Pooled S.E. after 24hrs") +
  ylim(0.0,1.05) +
  theme_bw(base_size = 12) +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    legend.position = "none",
    text = element_text(size = 15),
    axis.title.y = element_blank()
  ))

# Proportion squid missing after 1 hour by algal type across 2015-2019

(Figure4_1h <- ggplot(squid.summary.1hr, aes(x = Year, y = meanVal.squid.1hr, group = Habitat, col = Habitat)) +
  geom_line(size = 1) +
  geom_point(size = 3) +
  geom_errorbar(aes(ymax = meanVal.squid.1hr + pooled.se.squid.1hr, ymin = meanVal.squid.1hr - pooled.se.squid.1hr), width = 0) +
  scale_color_manual(values = habcolors) +
  labs(x = "", y = "Mean Proportion Squid Baits lost +/- Pooled S.E. after 1hr") +
  ylim(0.0,1.05) +
  theme_bw(base_size = 12) +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    legend.position = "none",
    text = element_text(size = 15),
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    axis.title.y = element_blank()
  ))

# Stacked 1 and 24 hour plots by algal type
(Figure4 <- plot_grid(Figure4_1h, Figure4_24h, ncol = 1, nrow = 2, labels = c("", "")))

#######################
###### Table 2 #######
#######################
# Summarize data by replicate
wp.summary <- wp %>% 
  
  group_by(habitat, location, videoNumber, algalType) %>%
  
  summarize(bites = sum(bite), richness = length(unique(specificEpithet)))

# Model total kg bites per hour as a function of treatments
bites_model <- lme(log10(bites) ~ algalType*habitat + location,
                   control = lmeControl(opt = "optim"),
                   random = list(videoNumber = ~ 1),
                   data = wp.summary)

# Type II test analysis of 1 hour video footage (analysis of deviance)
Anova(bites_model, type = "II")

rsquared(bites_model) 

#######################
###### Figure 5 #######
#######################
# Conduct post-hoc tests

pairwise <- as.data.frame(pairs(emmeans(bites_model, ~ algalType*habitat)))

pairwise$sig <- isSig(pairwise$p.value)

pairwise2 <- do.call(rbind, lapply(1:nrow(pairwise), function(i) {
  
  a <- strsplit(pairwise[i, "contrast"], "- ")[[1]]
  
  if(sub(" .*", "", a[1]) == sub(" .*", "", a[2])) data.frame(algalType = sub(" .*", "", a[1]) , pairwise[i, ]) else data.frame()
  
} ) )

# Plot results
habitat_partial <- as.data.frame(emmeans(bites_model, ~algalType:habitat))

habitat_partial$habitat <- recode(habitat_partial$habitat,
                                  "Reef" = "Fore Reef")

pairwise2$top <- habitat_partial %>% group_by(algalType) %>% 
  
  summarize(top = 10^max(upper.CL) + 0.1 * 10^max(upper.CL)) %>% .$top

pairwise2 <- subset(pairwise2, sig != "")

(Figure5 <- ggplot(habitat_partial, 
                aes(x = algalType, y = 10^emmean, group = habitat, shape = habitat, col = habitat)) +
    geom_errorbar(aes(ymax = 10^upper.CL, ymin = 10^lower.CL), width = 0.1,
                  position = position_dodge(width = 0.5)) +
    geom_point(size = 3,
               position = position_dodge(width = 0.5)) +
    annotate("text", x = pairwise2$algalType, y = pairwise2$top, label = pairwise2$sig) +
    labs(x = "", y = "Bite Rate") +
    scale_color_manual(values = habcolors) +
    theme_bw(base_size = 12) +
    theme(
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      legend.position = c(0.85, 0.865),
      legend.title = element_blank()
    )
)

#######################
###### Figure 6 #######
#######################

# Bites on weedpops from unique species of fish based on 1 h video footage
uniqueFish <- data.frame(unique(wp$species))

uniqueFish <- uniqueFish %>%

  rename(species = unique.wp.species.)

uniqueFish <- cbind(uniqueFish, bites = 0, habitat = "Fore Reef")

species_bites <- wp %>% group_by(habitat, location, videoNumber, algalType, species) %>%
  
  summarize(bites = sum(bite))

species_bites$habitat <- recode(species_bites$habitat, "Forereef" = "Fore Reef", "Reef" = "Fore Reef")

species_bites2 <- species_bites %>% 
  
  group_by(algalType, habitat, species) %>% summarize(bites = mean(bites, na.rm = T)) %>%
  
  droplevels()

# Create dataframe of total bites per fish over all algal types (sum of means), separated by habitat
species_bites3 <- full_join(species_bites2, uniqueFish) %>%

  group_by(habitat, species) %>% summarize(bites = sum(bites), algalType = "Total Bites")

allBites <- full_join(species_bites2, species_bites3)

allBites <- subset(allBites, bites != 0)

(Figure6 <- ggplot(allBites, aes(x = algalType, y = reorder(species, desc(species)), fill = habitat)) +
    geom_point(aes(size = bites), shape = 21) +
    scale_fill_manual(values = habcolors) +
    scale_size(range = c(1, 17), name = "Bite Rate", breaks = c(1,10,20,30,40)) +
    scale_y_discrete(limits = rev(levels(species_bites2$species))) +
    facet_grid(~habitat) +
    labs(x = "", y = "") +
    theme_bw(base_size = 12) +
    theme(
      axis.text.y = element_text(face = "italic"),
      axis.text.x = element_text(angle = 20, hjust = 1)
    )
)

#######################
###### Figure 7 #######
#######################

# Bites on squidpops from unique species of fish based on 1 h video footage

sp$habitat <- factor(sp$habitat, levels = c("Fore Reef", "Patch Reef", "Mangrove", "Seagrass"))

sp$fish_sp <- recode(sp$fish_sp, "S. diencaus" = "Stegastes diencaeus",
                      "S. aurofrenatum" = "Sparisoma aurofrenatum",
                      "O. chrysurus" = "Ocyurus chrysurus",
                      "M. plumieri" = "Malacanthus plumieri",
                      "L. triqueter" = "Lactophrys triqueter",
                      "L. jocu" = "Lutjanus jocu",
                      "L. griseus" = "Lutjanus griseus",
                      "L. apodus" = "Lutjanus apodus",
                      "H. plumierii" = "Haemulon plumierii",
                      "H. garnoti" = "Halichoeres garnoti",
                      "H. bivittatus" = "Halichoeres bivittatus",
                      "C. cruentata" = "Cephalopholis cruentata",
                      "H. plumierii?" = "Haemulon plumierii")

squid_bites <- sp %>% group_by(habitat, fish_sp) %>%
  
  summarize(count = n())

squid_bites$bait <- "squid"

(Figure7 <- ggplot(squid_bites, aes(x = bait, y = reorder(fish_sp, desc(fish_sp)), fill = habitat)) +
  geom_point(aes(size = count), shape = 21, col = "black",) +
  scale_size(range = c(2, 15), name = "Bite Rate", breaks = c(1,10,20,30,40)) +
  labs(x = "", y = "") +
  scale_fill_manual("",values = habcolors, guide = FALSE) +
  facet_grid(~habitat) +
  theme_bw(base_size = 12) +
  theme(
    axis.text.y = element_text(face = "italic"),
    axis.text.x = element_blank(),
    legend.title = element_text(size = 10),
    axis.ticks.x = element_blank()))

#######################
###### Figure 8 #######
#######################
assay$year_a <- assay$Year                        
assay$locality_a <- assay$locality
assay <- assay %>%
  unite_("event", c("locality_a", "year_a"), sep = "_")

RLS_weed <- left_join(RLSbiomass, assay, by = "event")
RLS_weed <- select(RLS_weed, c(site_code:Rope_ID, AlgalType:pct.lost.24hr))
colnames(RLS_weed) <- gsub("\\.x","",colnames(RLS_weed))

RLS_weed <- RLS_weed %>% mutate(Trophic.group = 
                                  ifelse(family == "Pomacanthidae",
                                         "Omnivore", Trophic.group))

algloss <- RLS_weed %>% subset %>% group_by(event, habitat, Year, locality) %>%
  summarize(baitloss = mean(pct.lost.24hr, na.rm = TRUE)) %>%
  filter(baitloss >= 0)

acanscarmass <- RLSbiomass %>% subset(family == "Acanthuridae" | family == "Scaridae") %>%
  group_by(event, habitat, Year, locality, location) %>%
  summarize(biomass = sum(mass), na.rm = TRUE)
acanscarmass <- left_join(algloss, acanscarmass, by = "event") %>% select(event:baitloss, biomass, location)
colnames(acanscarmass) <- gsub("\\.x","",colnames(acanscarmass))
acanscarmass$biomass[is.na(acanscarmass$biomass)] <- 0

alg <- RLS_weed %>% group_by(event, AlgalType) %>% 
  summarize(baitloss = mean(pct.lost.24hr, na.rm = TRUE)) %>%
  filter(!(is.na(AlgalType)))

alg <- left_join(acanscarmass, alg, by = "event")
alg <- select(alg, event:locality,biomass:baitloss.y, location)
colnames(alg) <- gsub("\\.y","",colnames(alg))

patchreefalg <- alg %>% subset(habitat == "Patch Reef") %>%
  mutate(logbiomass = log10(biomass + 1))

forereefalg <- alg %>% subset(habitat == "Fore Reef") %>% 
  mutate(logbiomass = log10(biomass + 1)) %>%
  filter(!(is.na(AlgalType)))

(Figure8A <- ggplot(forereefalg, aes(x = logbiomass, y = baitloss, colour = AlgalType, fill = AlgalType)) +
    geom_point(size = 2, position = "jitter") +
    geom_smooth(method = "lm") +
    scale_y_continuous("Proportion Missing After 24 Hours", limits = c(0,1.3)) +
    scale_x_log10("Biomass (log10): Acanthurids & Scarids") +
    ggtitle("Fore Reef") +
    scale_color_viridis_d() +
    scale_fill_viridis_d() +
    xlim(3.0, 4.0) +
    theme(plot.title = element_text(size = 12, hjust = 0.5),
          panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
          panel.background = element_blank(), axis.line = element_line(colour = "black"),
          axis.text = element_text(colour = "black", size = 12),
          axis.title = element_text(size = 12)))

(Figure8B <- ggplot(patchreefalg, aes(x = logbiomass, y = baitloss, colour = AlgalType, fill = AlgalType)) +
  geom_point(size = 2, position = "jitter") +
  geom_smooth(method = "lm") +
  scale_y_continuous("Proportion Missing After 24 Hours", limits = c(0,1.3)) +
  scale_x_log10("Biomass (log10): Acanthurids & Scarids") +
  ggtitle("Patch Reef") +
  scale_color_viridis_d() +
  scale_fill_viridis_d() +
  xlim(3.0, 4.0) +
  theme(plot.title = element_text(size = 12,hjust = 0.5),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"),
        axis.text = element_text(colour = "black", size = 12),
        axis.title = element_text(size = 12)))

#######################
###### Table 3 #######
#######################
# Model within reefs only
alg <- alg %>% mutate(logbiomass = log10(biomass + 1))

reefsum <- alg %>% filter(habitat == "Fore Reef" | habitat == "Patch Reef")

reefmod <- glm(baitloss ~ logbiomass*habitat + AlgalType*habitat + Year,
               family = "quasibinomial",
               data = reefsum)

Anova(reefmod, Type = "II")

############################
###### SUPPLEMENTALS #######
############################

##########################
####### Figure S1 ########
##########################
# Box plot of median proportion of macrophyte type consumed after 24 hours across habitats for all 5 years of data
(fig_box <- ggplot(assay.summary, aes(x = factor(Habitat, level = c('Fore Reef', 'Patch Reef', 'Mangrove', 'Seagrass', 'Bare Sand')), y = medVal, col = Habitat)) + 
   geom_boxplot() + 
   theme_classic() +
   theme(axis.text=element_text(size=12),
         axis.text.x = element_text(angle = 45, hjust = 1),
         axis.title = element_text(size=12),
         legend.position = "none"
   ) +
   scale_color_manual(values = habcolors) +
   labs(x = "", y = "Median Proportion Loss over 24h") +
   ylim(0, 1.0)
)

# Box plot of median proportion of macrophyte type consumed after 1 hour across habitats for all 5 years of data
(fig_box.1hr <- ggplot(assay.summary.1hr, aes(x = factor(Habitat, level = c('Fore Reef', 'Patch Reef', 'Mangrove', 'Seagrass', 'Bare Sand')), y = medvalue1, col = Habitat)) + 
    geom_boxplot() + 
    theme_classic() +
    theme(axis.text=element_text(size=12),
          axis.text.x = element_text(angle = 45, hjust = 1),
          axis.title = element_text(size=12),
          legend.position = "none"
    ) +
    scale_color_manual(values = habcolors) +
    labs(x = "", y = "Median Proportion Loss over 1h") +
    ylim(0, 1.0)
)

# Incorporate squidpops data for parallel analysis
(fig_box.squid <- ggplot(squid.summary, aes(x = factor(Habitat, level = c('Fore Reef', 'Patch Reef', 'Mangrove', 'Seagrass', 'Bare Sand')), y = medVal.squid, col = Habitat)) + 
    geom_boxplot() + 
    theme_classic() +
    theme(axis.text=element_text(size=12),
          axis.text.x = element_text(angle = 45, hjust = 1),
          axis.title = element_text(size=12),
          legend.position = "none"
    ) +
    scale_color_manual(values = habcolors) +
    labs(x = "", y = "   ") +
    ylim(0, 1.0)
)

# do it all again for 1 hour
# Box plot of median proportion of macrophyte type consumed after 1 hour across habitats for all 5 years of data

(fig_box.squid.1hr <- ggplot(squid.summary.1hr, aes(x = factor(Habitat, level = c('Fore Reef', 'Patch Reef', 'Mangrove', 'Seagrass', 'Bare Sand')), y = medVal.squid.1hr, col = Habitat)) + 
    geom_boxplot() + 
    theme_classic() +
    theme(axis.text=element_text(size=12),
          axis.text.x = element_text(angle = 45, hjust = 1),
          axis.title = element_text(size=12),
          legend.position = "none"
    ) +
    scale_color_manual(values = habcolors) +
    labs(x = "", y = "   ") +
    ylim(0, 1.0)
)
# 2-panel figure for 24 hours of squid and weed pops over 5 years
(pops5year24hr <- plot_grid(fig_box, fig_box.squid, ncol = 2, nrow = 1, labels = "",  hjust = -2.5))

# 2-panel figure for 1 hour of squid and weed pops over 5 years
(pops5year1hr <- plot_grid(fig_box.1hr, fig_box.squid.1hr, ncol = 2, nrow = 1, labels = "", hjust = -2.5))

##########################
####### Table S2 ########
##########################
# Model bait loss by year and habitat
squid24 <- squid %>% filter(!is.na(pct.lost.24hr))

# For one hour
hab_year_1h_squid <- glm(pct.lost.1hr ~ Year * Habitat + location,
                         family = "quasibinomial",
                         data = squid)

Anova(hab_year_1h_squid, type = "II")

# For 24 hours
hab_year_24h_squid <- glm(pct.lost.24hr ~ Year * Habitat + location,
                          family = "quasibinomial",
                          data = squid24)

Anova(hab_year_24h_squid, type = "II")

####################################
####### Table S3 + Figure 2 ########
####################################
# Calculate coefficient of variation for 1 hour data by site for weedpops
coeffvarweed <- assay %>% 
  subset(locality != "Twin Cays Sand" & locality != "Tobacco Seagrass") %>%
  group_by(Habitat, locality, Year) %>%
  summarize(meanprop1hr = mean(pct.lost.1hr), meanprop24hr = mean(pct.lost.24hr)) %>%
  group_by(Habitat, locality) %>%
  summarize(covar1hr = sd(meanprop1hr, na.rm = TRUE)/mean(meanprop1hr, na.rm = TRUE), 
            covar24hr = sd(meanprop24hr, na.rm = TRUE)/mean(meanprop24hr, na.rm = TRUE))

varsumweed <- coeffvarweed %>% group_by(Habitat) %>%
  summarize(meanvar1hr = mean(covar1hr, na.rm = TRUE), sevar1hr = se(covar1hr),
            meanvar24hr = mean(covar24hr), sevar24hr = se(covar24hr))

# Model bait loss by habitat and time for 1 hr and 24 hours weedpops
comod <- glm(covar1hr ~ Habitat,
             data = coeffvarweed)

hist(resid(comod))
summary(comod)

Anova(comod, type = "II")
rsquared(comod)

pairwise <- as.data.frame(pairs(emmeans(comod, ~ Habitat)))

pairwise$sig <- isSig(pairwise$p.value)

letters <- as.data.frame(cldList(p.value ~ contrast,
                                 data = pairwise,
                                 threshold = 0.05))
letters$Group <- recode(letters$Group, "BareSand" = "Bare Sand",
                        "ForeReef" = "Fore Reef",
                        "PatchReef" = "Patch Reef")

varsumweed1 <- left_join(varsumweed, letters, by = c("Habitat" = "Group")) %>%
  mutate(Habitat = fct_relevel(Habitat, "Fore Reef", "Patch Reef", "Mangrove", 
                               "Seagrass", "Bare Sand"))
varsumweed1[is.na(varsumweed1)] <- 0 

(var1weed <- ggplot(varsumweed1, aes(x = Habitat, y = meanvar1hr, fill = Habitat)) +
  geom_bar(stat = "identity", position = "dodge", color = "black") +
  geom_errorbar(aes(ymax = meanvar1hr + sevar1hr, ymin = meanvar1hr - sevar1hr),
                position = pd, width = 0.2) + 
  scale_y_continuous("Mean Coefficient of Variation", expand = c(0,0), limits = c(0,2.2)) +
  scale_x_discrete("") +
  annotate("text", x = varsumweed1$Habitat, y = varsumweed1$meanvar1hr + varsumweed1$sevar1hr + 0.1, label = varsumweed1$Letter) +
  ggtitle("Weedpops: 1 Hr") +
  scale_fill_manual("", values = c(habcolors)) +
  theme(plot.title = element_text(size = 12,hjust = 0.5),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"),
        axis.text.x = element_text(colour = "black", size = 10, angle = 45, hjust = 1),
        axis.text.y = element_text(colour = "black", size = 10, hjust = 1),
        axis.title = element_text(size = 12),
        legend.position = "none"))

comod24 <- glm(covar24hr ~ Habitat,
               data = coeffvarweed)

summary(comod24)

Anova(comod24, type = "II")
rsquared(comod24)

pairwise24 <- as.data.frame(pairs(emmeans(comod24, ~ Habitat)))

pairwise24$sig <- isSig(pairwise24$p.value)

letters <- as.data.frame(cldList(p.value ~ contrast,
                                 data = pairwise24,
                                 threshold = 0.05))
letters$Group <- recode(letters$Group, "BareSand" = "Bare Sand",
                        "ForeReef" = "Fore Reef",
                        "PatchReef" = "Patch Reef")

varsumweed24 <- left_join(varsumweed, letters, by = c("Habitat" = "Group")) %>%
  mutate(Habitat = fct_relevel(Habitat, "Fore Reef", "Patch Reef", "Mangrove", 
                               "Seagrass", "Bare Sand"))
varsumweed24[is.na(varsumweed24)] <- 0 


(var24weed <- ggplot(varsumweed24, aes(x = Habitat, y = meanvar24hr, fill = Habitat)) +
  geom_bar(stat = "identity", position = "dodge", color = "black") +
  geom_errorbar(aes(ymax = meanvar24hr + sevar24hr, ymin = meanvar24hr - sevar24hr),
                position = pd, width = 0.2) + 
  scale_y_continuous("Mean Coefficient of Variation", expand = c(0,0), limits = c(0,2.2)) +
  scale_x_discrete("") +
  annotate("text", x = varsumweed24$Habitat, y = varsumweed24$meanvar24hr + varsumweed24$sevar24hr + 0.07, label = varsumweed24$Letter) +
  ggtitle("Weedpops: 24 Hrs") +
  scale_fill_manual("", values = c(habcolors)) +
  theme(plot.title = element_text(size = 12,hjust = 0.5),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"),
        axis.text.x = element_text(colour = "black", size = 10, angle = 45, hjust = 1),
        axis.text.y = element_text(colour = "black", size = 10, hjust = 1),
        axis.title = element_text(size = 12),
        legend.position = "none"))

# Calculate coefficient of variation for 1 hour data by site for squidpops
coeffvarsquid <- squid %>% group_by(Habitat, locality) %>% 
  summarize(covar1hr = sd(pct.lost.1hr, na.rm = TRUE)/mean(pct.lost.1hr, na.rm = TRUE), 
            covar24hr = sd(pct.lost.24hr, na.rm = TRUE)/mean(pct.lost.24hr, na.rm = TRUE))


varsumsquid <- coeffvarsquid %>% group_by(Habitat) %>%
  subset(locality != "Blueground Seagrass") %>%
  summarize(meanvar1hr = mean(covar1hr), sevar1hr = se(covar1hr),
            meanvar24hr = mean(covar24hr), sevar24hr = se(covar24hr))

# Squid 1 hr
comod <- glm(covar1hr ~ Habitat,
             data = coeffvarsquid)
summary(comod)

Anova(comod, type = "II")
rsquared(comod)

pairwise <- as.data.frame(pairs(emmeans(comod, ~ Habitat)))

pairwise$sig <- isSig(pairwise$p.value)

letters <- as.data.frame(cldList(p.value ~ contrast,
                                 data = pairwise,
                                 threshold = 0.05))
letters$Group <- recode(letters$Group, "BareSand" = "Bare Sand",
                        "ForeReef" = "Fore Reef",
                        "PatchReef" = "Patch Reef")

varsumsquid1 <- left_join(varsumsquid, letters, by = c("Habitat" = "Group")) %>%
  mutate(Habitat = fct_relevel(Habitat, "Fore Reef", "Patch Reef", "Mangrove", 
                               "Seagrass", "Bare Sand"))

(var1squid <- ggplot(varsumsquid1, aes(x = Habitat, y = meanvar1hr, fill = Habitat)) +
  geom_bar(stat = "identity", position = "dodge", color = "black") +
  geom_errorbar(aes(ymax = meanvar1hr + sevar1hr, ymin = meanvar1hr - sevar1hr),
                position = pd, width = 0.2) + 
  scale_y_continuous("Mean Coefficient of Variation", expand = c(0,0), limits = c(0,2.2)) +
  scale_x_discrete("") +
  annotate("text", x = varsumsquid1$Habitat, y = varsumsquid1$meanvar1hr + varsumsquid1$sevar1hr + 0.07, label = varsumsquid1$Letter) +
  ggtitle("Squidpops: 1 Hr") +
  scale_fill_manual("", values = c(habcolors)) +
  theme(plot.title = element_text(size = 12,hjust = 0.5),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"),
        axis.text.x = element_text(colour = "black", size = 10, angle = 45, hjust = 1),
        axis.text.y = element_text(colour = "black", size = 10, hjust = 1),
        axis.title = element_text(size = 12),
        legend.position = "none"))

# Squid 24 hours

comod24 <- glm(covar24hr ~ Habitat,
               data = coeffvarsquid)
summary(comod24)

Anova(comod24, type = "II")
rsquared(comod24)

pairwise <- as.data.frame(pairs(emmeans(comod24, ~ Habitat)))

pairwise$sig <- isSig(pairwise$p.value)

letters <- as.data.frame(cldList(p.value ~ contrast,
                                 data = pairwise,
                                 threshold = 0.05))
letters$Group <- recode(letters$Group, "BareSand" = "Bare Sand",
                        "ForeReef" = "Fore Reef",
                        "PatchReef" = "Patch Reef")

varsumsquid24 <- left_join(varsumsquid, letters, by = c("Habitat" = "Group")) %>%
  mutate(Habitat = fct_relevel(Habitat, "Fore Reef", "Patch Reef", "Mangrove", 
                               "Seagrass", "Bare Sand"))

(var24squid <- ggplot(varsumsquid24, aes(x = Habitat, y = meanvar24hr, fill = Habitat)) +
  geom_bar(stat = "identity", position = "dodge", color = "black") +
  geom_errorbar(aes(ymax = meanvar24hr + sevar24hr, ymin = meanvar24hr - sevar24hr),
                position = pd, width = 0.2) + 
  scale_y_continuous("Mean Coefficient of Variation", expand = c(0,0), limits = c(0,2.2)) +
  scale_x_discrete("") +
  annotate("text", x = varsumsquid24$Habitat, y = varsumsquid24$meanvar24hr + varsumsquid24$sevar24hr + 0.05, label = varsumsquid24$Letter) +
  ggtitle("Squidpops: 24 Hrs") +
  scale_fill_manual("", values = c(habcolors)) +
  theme(plot.title = element_text(size = 12,hjust = 0.5),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"),
        axis.text.x = element_text(colour = "black", size = 10, angle = 45, hjust = 1),
        axis.text.y = element_text(colour = "black", size = 10, hjust = 1),
        axis.title = element_text(size = 12),
        legend.position = "none"))

Figure2 <- (grid.arrange(var1weed,var24weed,var1squid,var24squid,nrow = 2))

##########################
####### Table S4 ########
##########################
RLS_pops <- left_join(RLSbiomass, squid, by = "event")
RLS_pops <- select(RLS_pops, c("Year.x":"Trophic.group",
                               "Date.Deployed":"Detachment.24hr",
                               "pct.lost.1hr":"location.y"))
colnames(RLS_pops) <- gsub("\\.x","",colnames(RLS_pops))
colnames(RLS_pops) <- gsub("\\.y","",colnames(RLS_pops))


# Model Biomass & Habitat
biomasssummary <- RLS_pops %>% group_by(habitat, Year, location, event) %>% 
  summarize(biomass = sum(mass, na.rm = TRUE), baitloss = mean(pct.lost.24hr, na.rm = TRUE)) %>%
  filter(!(is.na(baitloss)))

predmasssummary <- RLS_pops %>% subset(Trophic.group == "Benthic invertivore"|Trophic.group == "Omnivore"|
                                         Trophic.group == "Higher carnivore") %>% 
  subset(family != "Gobiidae" & family != "Atherinidae") %>% droplevels() %>%
  group_by(habitat, Year, location, event) %>% 
  summarize(biomass = sum(mass, na.rm = TRUE), baitloss = mean(pct.lost.24hr, na.rm = TRUE)) %>%
  filter(!(is.na(baitloss)))

vidspsum <- RLS_pops %>% subset(family == "Labridae"|family == "Lutjanidae"|
                                  family == "Haemulidae") %>% droplevels() %>%
  group_by(habitat, Year, location, event) %>% 
  summarize(biomass = sum(mass, na.rm = TRUE), baitloss = mean(pct.lost.24hr, na.rm = TRUE)) %>%
  filter(!(is.na(baitloss)))

biomasslog <- biomasssummary %>% mutate(biomass = log(biomass + 10))
predmasslog <- predmasssummary %>% mutate(biomass = log(biomass + 10))
vidsplog <- vidspsum %>% mutate(biomass = log(biomass + 10))


allfish_mod <- glm(baitloss ~ biomass * habitat + Year + location,
                   family = "quasibinomial",
                   data = biomasslog)

# Get model results
Anova(allfish_mod, type = "II")

# Model "Predatory" Fish Species Biomass & Habitat
predmass_model <- glm(baitloss ~ biomass*habitat + Year + location,
                      family = "quasibinomial",
                      data = predmasslog)

# Get model results
Anova(predmass_model, type = "II")

# Model Labrids, Lutjanids, and Haemulids Biomass & Habitat
vidspmod <- glm(baitloss ~ biomass*habitat + Year + location,
                family = "quasibinomial",
                data = vidsplog)

# Get model results
Anova(vidspmod, type = "II")

##########################
####### Table S5 ########
##########################
RLSbiomass <- select(RLSbiomass, -c(Habitat))

totmass <- RLSbiomass %>% subset(method == 1 & phylum == "Chordata") %>% 
  group_by(event, habitat, Year, location) %>%
  summarize(biomass = sum(mass), na.rm = TRUE)
totmass <- left_join(algloss, totmass, by = "event") %>% select(event:baitloss, biomass, location)
colnames(totmass) <- gsub("\\.x","",colnames(totmass))

herbmass <- RLSbiomass %>% subset(method == 1) %>%
  subset(Trophic.group == "Omnivore" | Trophic.group == "Scraping herbivore" |
           Trophic.group == "Browsing herbivore" | Trophic.group == "Algal farmer") %>% 
  group_by(event, habitat, Year, location) %>%
  summarize(biomass = sum(mass), na.rm = TRUE)
herbmass <- left_join(algloss, herbmass, by = "event") %>% select(event:baitloss, biomass, location)
colnames(herbmass) <- gsub("\\.x","",colnames(herbmass))
herbmass$biomass[is.na(herbmass$biomass)] <- 0


totmasslog <- totmass %>% mutate(biomass = log(biomass + 10))
herbmasslog <- herbmass %>% mutate(biomass = log(biomass + 10))
acanscarmasslog <- acanscarmass %>% mutate(biomass = log(biomass + 10))

# All fish
totmassmod <- glm(baitloss ~ habitat*biomass + Year + location,
                  family = "quasibinomial",
                  data = totmasslog)

# Get model results
Anova(totmassmod, type = "II")

# Herbivores
herbmassmod <- glm(baitloss ~ habitat*biomass + Year + location,
                   family = "quasibinomial",
                   data = herbmasslog)

# Get model results
Anova(herbmassmod, type = "II")

# Acanthurids and Scarids
acanscarmod <- glm(baitloss ~ habitat*biomass + Year + location,
                   family = "quasibinomial",
                   data = acanscarmass)

# Get model results
Anova(acanscarmod, type = "II")

##########################
####### Figure S2 ########
##########################
# Summarize weedpops proportion lost through time by location (24 hours)
algal24hrSup <- assay %>%
  
  mutate(
    s = sqrt((value * (1 - value)/n))) %>%
  
  group_by(location, Year) %>%
  
  summarize(
    medVal.weed = median(value),
    meanVal.weed = mean(value),
    pooled.s.weed = pooled.sd(s, n),
    pooled.se.weed = pooled.s.weed/sqrt(sum(n))
  )

# Summarize weedpops proportion lost through time by location (1 hour)
algal1hrSup <- assay %>%
  
  mutate(
    s = sqrt((value1 * (1 - value1)/n))) %>%
  
  group_by(location, Year) %>%
  
  summarize(
    medVal.weed.1hr = median(value1),
    meanVal.weed.1hr = mean(value1),
    pooled.s.weed.1hr = pooled.sd(s, n),
    pooled.se.weed.1hr = pooled.s.weed.1hr/sqrt(sum(n))
  )

# Summarize squidpops proportion lost through time by location (24 hour)
squid24hrSup <- squid %>% drop_na(Detachment.24hr)

squid24hrSup <- squid24hrSup %>%
  mutate(
    n.squid = as.numeric(stakes_remaining_24_hr),
    Detachment.24hr = as.numeric(Detachment.24hr),
    value.squid = Detachment.24hr/n.squid
  ) %>%
  
  mutate(
    s.squid = sqrt((value.squid * (1 - value.squid)/n.squid))
  ) %>%
  
  group_by(location, Year) %>%
  
  summarize(
    medVal.squid = median(value.squid),
    meanVal.squid = mean(value.squid),
    pooled.s.squid = pooled.sd(s.squid, n.squid),
    pooled.se.squid = pooled.s.squid/sqrt(sum(n.squid))
  )

# Summarize squidpops proportion lost through time by location (1 hour)

squid1hrSup <- squid %>% drop_na(Detachment.1hr)

squid1hrSup <- squid1hrSup %>%
  mutate(
    n.squid.1hr = as.numeric(stakes_remaining_24_hr),
    Detachment.1hr = as.numeric(Detachment.1hr),
    value.squid.1hr = Detachment.1hr/n.squid.1hr
  ) %>%
  
  mutate(
    s.squid.1hr = sqrt((value.squid.1hr * (1 - value.squid.1hr)/n.squid.1hr))
  ) %>%
  
  group_by(location, Year) %>%
  
  summarize(
    medVal.squid.1hr = median(value.squid.1hr),
    meanVal.squid.1hr = mean(value.squid.1hr),
    pooled.s.squid.1hr = pooled.sd(s.squid.1hr, n.squid.1hr),
    pooled.se.squid.1hr = pooled.s.squid.1hr/sqrt(sum(n.squid.1hr))
  )

# Proportion squid missing after 24 h across 2015-2019

(FigureS2_24squid <- ggplot(squid24hrSup, aes(x = Year, y = meanVal.squid, group = location, col = location)) +
    geom_line(size = 1) +
    geom_point(size = 3) +
    geom_errorbar(aes(ymax = meanVal.squid + pooled.se.squid, ymin = meanVal.squid - pooled.se.squid), width = 0) +
    scale_fill_manual(values = cbPalette) +
    labs(x = "", y = "Mean Proportion Squid Baits lost +/- S.E. after 24 h") +
    ylim(0.0,1.05) +
    theme_bw(base_size = 12) +
    theme(
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      legend.position = "",
      text = element_text(size = 15),
      axis.text.x = element_blank(),
      axis.text.y = element_blank(),
      axis.title.y = element_blank()
    ))

# Proportion squid missing after 1 h across 2015-2019

(FigureS2_1squid <- ggplot(squid1hrSup, aes(x = Year, y = meanVal.squid.1hr, group = location, col = location)) +
    geom_line(size = 1) +
    geom_point(size = 3) +
    geom_errorbar(aes(ymax = meanVal.squid.1hr + pooled.se.squid.1hr, ymin = meanVal.squid.1hr - pooled.se.squid.1hr), width = 0) +
    scale_fill_manual(values = cbPalette) +
    labs(x = "", y = "Mean Proportion Squid Baits lost +/- S.E. after 1 h") +
    ylim(0.0,1.05) +
    theme_bw(base_size = 12) +
    theme(
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      legend.position = "",
      text = element_text(size = 15),
      axis.text.x = element_blank(),
      axis.title.y = element_blank()
    ))

# Proportion macrophytes missing after 24 h across 2015-2019

(FigureS2_24weed <- ggplot(algal24hrSup, aes(x = Year, y = meanVal.weed, group = location, col = location)) +
    geom_line(size = 1) +
    geom_point(size = 3) +
    geom_errorbar(aes(ymax = meanVal.weed + pooled.se.weed, ymin = meanVal.weed - pooled.se.weed), width = 0) +
    scale_fill_manual(values = cbPalette) +
    labs(x = "", y = "Mean Proportion Macrophytes lost +/- S.E. after 24 h") +
    ylim(0.0,1.05) +
    theme_bw(base_size = 12) +
    theme(
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      legend.position = "",
      text = element_text(size = 15),
      axis.text.y = element_blank(),
      axis.title.y = element_blank()
      ))

# Proportion macrophytes missing after 1 h across 2015-2019

(FigureS2_1weed <- ggplot(algal1hrSup, aes(x = Year, y = meanVal.weed.1hr, group = location, col = location)) +
    geom_line(size = 1) +
    geom_point(size = 3) +
    geom_errorbar(aes(ymax = meanVal.weed.1hr + pooled.se.weed.1hr, ymin = meanVal.weed.1hr - pooled.se.weed.1hr), width = 0) +
    scale_fill_manual(values = cbPalette) +
    labs(x = "", y = "Mean Proportion Macrophytes lost +/- S.E. after 1 h") +
    ylim(0.0,1.05) +
    theme_bw(base_size = 12) +
    theme(
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      legend.position = "",
      text = element_text(size = 15),
      #axis.text.x = element_blank(),
      #axis.ticks.x = element_blank(),
      axis.title.y = element_blank()
    ))

# Stacked 1 and 24 hour plots
(FigureS2 <- plot_grid(FigureS2_1squid, FigureS2_24squid, FigureS2_1weed, FigureS2_24weed, ncol = 2, nrow = 2, labels = c("", "")))

##########################
####### Figure S3 ########
##########################
###### Heat maps representing the squidpop and weedpop consumer fish presence over 5 years

# Squidpop consumers
squidSp <- RLSbiomass %>%
  subset(scientific_name == "Stegastes diencaeus" | scientific_name == "Sparisoma aurofrenatum" |
           scientific_name == "Ocyurus chrysurus" | scientific_name == "Malacanthus plumieri" |
           scientific_name == "Lutjanus jocu" | scientific_name == "Lutjanus griseus" |
           scientific_name == "Lutjanus apodus" | scientific_name == "Lactophrys triqueter" |
           scientific_name == "Halichoeres garnoti" | scientific_name == "Halichoeres bivittatus" |
           scientific_name == "Haemulon plumierii" | scientific_name == "Cephalopholis cruentata")

# Create a summary table from the reduced list
squidSum <- squidSp %>%
  group_by(Year, habitat, scientific_name) %>%
  summarize(abundance = sum(size_count)) %>%
  ungroup %>%
  complete(Year, habitat, scientific_name)

(FigureS3A <- ggplot(squidSum, aes(Year, factor(scientific_name, 
                                  levels = rev(levels(factor(scientific_name)))), fill= sqrt(abundance))) + 
  geom_tile(color = "black") +
  facet_grid(~factor(habitat, levels = c('Fore Reef', 'Patch Reef', 'Mangrove', 'Bare Sand', 'Seagrass'))) +
  scale_fill_viridis("Total Abundance (sqrt)", limits = c(0,35), discrete = FALSE, na.value = "white", direction = -1) +
  scale_y_discrete("") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"),
        axis.text.y = element_text(colour = "black", size = 8, face = "italic"), 
        axis.text.x = element_text(colour = "black", size = 8, angle = 45, hjust = 1), 
        axis.title.x = element_blank(),
        plot.title = element_text(size = 13, hjust = 1, vjust = -10),
        legend.title = element_text(size = 8),
        legend.text = element_text(size = 8, margin = margin(b = 0.2, unit = 'cm')),
        strip.placement = "bottom",
        strip.text.x = element_text(size = 8),
        plot.margin = unit(c(.5,.5,.5,0), "cm")))

# Weedpop consumers
weedSp <- RLSbiomass %>%
  subset(scientific_name == "Acanthurus chirurgus" | scientific_name == "Acanthurus coeruleus" |
           scientific_name == "Acanthurus tractus" | scientific_name == "Cantherhinus pullus" |
           scientific_name == "Halichoeres garnoti" | scientific_name == "Pomacanthus arcuatus" |
           scientific_name == "Pomacanthus paru" | scientific_name == "Scarus iseri" |
           scientific_name == "Sparisoma aurofrenatum" | scientific_name == "Sparisoma rubripinne" |
           scientific_name == "Stegastes diencaeus" | scientific_name == "Stegastes partitus" |
           scientific_name == "Stegastes planifrons" | scientific_name == "Thalassoma bifasciatum")

# Create a summary table from reduced list
weedSum <- weedSp %>%
  group_by(Year, habitat, scientific_name) %>% summarize(abundance = sum(size_count)) %>% 
  ungroup %>% complete(Year,habitat,scientific_name)

(FigureS3B <- ggplot(weedSum, aes(Year, factor(scientific_name, 
                                 levels = rev(levels(factor(scientific_name)))), fill= sqrt(abundance))) + 
  geom_tile(color = "black") +
  facet_grid(~factor(habitat, levels = c('Fore Reef', 'Patch Reef', 'Mangrove', 'Bare Sand', 'Seagrass'))) +
  scale_fill_viridis("Total Abundance (sqrt)", limits = c(0,35), discrete = FALSE, na.value = "white", direction = -1) +
  scale_y_discrete("") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"),
        axis.text.y = element_text(colour = "black", size = 8, face = "italic"), 
        axis.text.x = element_text(colour = "black", size = 8, angle = 45, hjust = 1), 
        axis.title.x = element_blank(),
        plot.title = element_text(size = 13, hjust = 1, vjust = -10),
        legend.title = element_text(size = 8),
        legend.text = element_text(size = 8, margin = margin(b = 0.2, unit = 'cm')),
        strip.placement = "bottom",
        strip.text.x = element_text(size = 8),
        plot.margin = unit(c(.5,.5,.5,0), "cm")))

##########################
####### Figure S4 ########
##########################
# Create sample-by-species presence-absence matrix
fish_mat <- wp %>% dplyr::select (habitat, location, videoNumber, species, bite) %>% 
  
  pivot_wider(names_from = "species", values_from = "bite", values_fn = list(bite = sum)) %>%
  
  mutate_at(vars(`Thalassoma bifasciatum`:`Cantherhines pullus`), ~replace_na(., 0)) %>%
  
  mutate_at(vars(`Thalassoma bifasciatum`:`Cantherhines pullus`), ~replace(., . > 1, 1))


# Create sample-by-diet item bite matrix
diet_mat <- wp %>% dplyr::select (habitat, location, videoNumber, algalType, bite) %>% 
  
  pivot_wider(names_from = "algalType", values_from = "bite", values_fn = list(bite = sum)) %>%
  
  mutate_at(vars(`Dictyota`:`Acanthophora`), ~replace_na(., 0))

# Conduct RDA
RDA <- rda(diet_mat[, -(1:3)], fish_mat[, -(1:3)])

# Plot results
sites <- cbind.data.frame(diet_mat[, 1:3], summary(RDA)$sites[, 1:2])

sites$habitat <- as.factor(sites$habitat)

levels(sites$habitat) <- c("Patch Reef", "Fore Reef")

algalType <- as.data.frame(summary(RDA)$species[, 1:2])

species <- as.data.frame(summary(RDA)$biplot[, 1:2])

rownames(species) <- gsub("\\`", "", rownames(species))

mult <- attributes(plot(RDA)$biplot)$arrow.mul

anova(RDA, type = "II")

(FigureS4 <- ggplot() +
    geom_point(data = sites, aes(x = RDA1, y = RDA2, shape = habitat, color = habitat)) +
    scale_shape_manual(values = c(0, 2), name = "") +
    scale_color_manual(values=c("midnightblue","steelblue1"), name = "") +
    geom_text(data = algalType, aes(x = RDA1, y = RDA2, label = rownames(algalType)), col = "red", size = 6) +
    geom_hline(yintercept = 0, linetype = "dotted") +
    geom_vline(xintercept = 0, linetype = "dotted") +
    coord_fixed(ratio = 1) +
    lims(x = c(-7.5, 12.5)) +
    geom_segment(data = species, aes(x = 0, xend = mult * RDA1, y = 0, yend = mult * RDA2), 
                 color = "black", arrow = arrow(length = unit(0.01, "npc"))) +
    geom_text(data = species, aes(x = mult * RDA1, y = mult * RDA2, label = rownames(species), 
                                  hjust = 0.5*(1 - sign(RDA1)), vjust = 0.5*(1 - sign(RDA2))),
              col = "black", size = 4) +
    theme_bw(base_size = 12) +
    theme(
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank(),
      legend.position = c(0.15, 0.9),
      legend.title = element_blank()
    )
)

##########################
####### Figure S5 ########
##########################
# Fish biomass of key consumers by habitat and year
keyfish <- RLSbiomass %>% subset(family == "Acanthuridae"|
                                   family == "Scaridae"|
                                   family == "Lutjanidae"|
                                   family == "Haemulidae"|
                                   family == "Labridae") %>%
  
  group_by(locality, habitat, Year, family) %>%
  
  summarize(biomass = sum(mass), abundance = sum(size_count)) %>%
  
  group_by(habitat, Year, family) %>%
  
  mutate(logbiomass = log10(biomass+1)) %>%
  
  summarize(meanmass = mean(logbiomass), semass = se(logbiomass), meanab = mean(abundance), seab = se(abundance))

(FigureS5 <- ggplot(keyfish, aes(x = Year, y = meanmass, colour = family)) +
  facet_wrap(~habitat) +
  geom_line(size = 1, position = pd) +
  geom_point(size = 3, position = pd) +
  geom_errorbar(aes(ymax = meanmass + semass, ymin = meanmass - semass),
                position = pd, width = 0.2) +  
  scale_x_continuous("", breaks = c(2015,2016,2017,2018,2019)) +
  ylab("Mean Biomass (g log10/100m^2)") +
  scale_color_viridis_d() +
  theme(plot.title = element_text(size = 12,hjust = 0.5),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), axis.line = element_line(colour = "black"),
        axis.text = element_text(colour = "black", size = 12),
        axis.title = element_text(size = 12)))

# fin
